@@ -47,10 +47,10 @@ class Collector(ABC):
         self.update_config()
         self.logger.info(f"Collecting {self.name} data")
         self.run()
-        time.sleep(self.exec_time)
 
     def execute(self, cmd):
         command = str(cmd)
+        self.logger.debug(f"Executing command: {command}")
         output = subprocess.run(
             command, shell=True, stdout=subprocess.PIPE
         ).stdout.decode("utf-8")
