@@ -46,7 +46,9 @@ class Hydra(Collector):
         )
 
         records = self.cursor.fetchall()
+        self.logger.debug(f"Processing {len(records)} IP addresses")
         for record in records:
+            self.logger.debug(f"Processing IP address: {record[0]}")
             self.__hydra__(record[0])
 
     def __hydra__(self, ip):
