@@ -55,10 +55,9 @@ class Netdiscover(Collector):
 
         for subnet in common_subnets:
             subnet = subnet + subnet_config if not "--" in subnet else subnet
-            command = f"arp-scan {subnet}"
-            self.logger.debug(f"Command: {command}")
+            self.logger.debug(f"Scanning {subnet} with arp-scan")
 
-            output = self.execute(command)
+            output = self.execute(f"arp-scan {subnet}")
             for line in output.split("\n"):
                 self.parse_line(line)
 
