@@ -43,7 +43,9 @@ class Nmap(Collector):
         )
 
         ips = self.cursor.fetchall()
+        self.logger.debug(f"Processing {len(ips)} IP addresses")
         for ip in ips:
+            self.logger.debug(f"Processing IP address: {ip[0]}")
             self.__nmap__(ip[0])
 
     def __nmap__(self, ip):
