@@ -25,7 +25,7 @@ from digital_hydrant.collector_queue import CollectorQueue
 from digital_hydrant.ping import Ping
 from digital_hydrant.args import args
 from digital_hydrant.process_manager import ProcessManager
-from digital_hydrant.config import db_path, update_config
+from digital_hydrant.config import db_path, update_config, check_default_config
 
 
 def create_tables(logger):
@@ -49,7 +49,7 @@ def check_required_ubuntu_packages():
     missing = False
     packages = {
         "arp-scan": "https://github.com/royhills/arp-scan",
-        "dhcpcd5": "https://wiki.archlinux.org/index.php/Dhcpcd",
+        "dhcpcd": "https://wiki.archlinux.org/index.php/Dhcpcd",
         "iw": "https://wireless.wiki.kernel.org/en/users/documentation/iw",
         "lldpd": "https://lldpd.github.io/lldpd/installation.html",
         "ifconfig": "(https://wiki.linuxfoundation.org/networking/net-tools",
@@ -72,6 +72,7 @@ def check_required_ubuntu_packages():
 
 
 def run():
+    check_default_config()
     missing = False if args.force else check_required_ubuntu_packages()
 
     if args.init is not None:
