@@ -23,10 +23,13 @@ days_of_the_week = [
     "thursday",
     "friday",
     "saturday",
-    "sunday",
 ]
 
 
+def format_time(t):
+    return t.strftime("%Y-%m-%d %H:%M:%S") if t else ""
+
+
 class ProcessManager:
     scheduler = None
 
@@ -37,7 +40,10 @@ class ProcessManager:
         self.process_details = {}
         self.jobs = {}
         self.job_schedules = {}
+        self.processes = {}
         self.scheduler = schedule.Scheduler()
+        self.last_retry = {}
+        self.logger.debug(f"Initialized ProcessManager: {manager_name}")
 
     def error_wrapper(self, f, name):
         @functools.wraps(f)
@@ -56,15 +62,38 @@ class ProcessManager:
                         "timestamp": now() * 1000,
                     }
                 )
+
+                if self.job_schedules[name] == "* * * * *" and (
+                    name not in self.last_retry or now() - self.last_retry[name] > 10
+                ):
+                    self.run_job_once(name)
+                    self.last_retry[name] = now()
+                    self.logger.info(f"Retrying {name}")
+
                 raise
 
         return wrapped
 
+    def print_processes(self):
+        details = ""
+
+        for name, process in self.processes.items():
+            details += f"name: {name}, is_alive: {process.is_alive()}, pid: {process.pid}, exitcode: {process.exitcode}\n"
+        return details
+
+    def print_jobs(self):
+        details = ""
+
+        for name, job in self.jobs.items():
+            details += f"name: {name}, schedule: {self.job_schedules[name]}, last run: {format_time(job.last_run)}, next_run: {format_time(job.next_run) if self.job_schedules[name] != '* * * * *' else ''}\n"
+        return details
+
     def add_process(self, name, target, args=()):
         self.process_details[name] = {
             "target": self.error_wrapper(target, name),
             "args": args,
         }
+        self.logger.debug(f"Added process: {name}")
 
     def is_scheduled(self, name):
         return name in self.jobs and isinstance(self.jobs[name], schedule.Job)
@@ -78,6 +107,8 @@ class ProcessManager:
         )
         p.start()
 
+        self.processes[name] = p
+
     def run_job_once(self, name):
         self.run_job(name)
 
@@ -174,6 +205,7 @@ class ProcessManager:
                 elif not enabled and scheduled:
                     self.scheduler.cancel_job(self.jobs[name])
                     self.jobs.pop(name, None)
+                    self.logger.info(f"Removed job: {name}")
                 elif (
                     enabled
                     and scheduled
@@ -186,8 +218,17 @@ class ProcessManager:
                 if scheduled:
                     active.append(name)
 
-            if counter == 20:
-                self.logger.info(f"Active processes: {active}")
+                if name in self.processes and self.processes[name].exitcode == 0:
+                    self.processes.pop(name, None)
+                    self.logger.debug(f"Process {name} successfully completed")
+
+            if counter == 10:
+                self.logger.info(
+                    f"Active Processes: \n{self.print_processes()}"
+                ) if len(self.processes) else self.logger.info("No Active Processes")
+                self.logger.info(f"Scheduled Processes: \n{self.print_jobs()}") if len(
+                    self.jobs
+                ) else self.logger.info("No Scheduled Processes")
                 counter = 0
             sleep(5)
             counter += 1
