@@ -4,20 +4,16 @@ import sqlite3
 
 
 class Processor:
-    def __init__(self, db_name=None):
+    def __init__(self):
         self.logger = logging.getLogger(__name__)
         self.table_name = "unique_ips"
 
         try:
-            self.conn = sqlite3.connect(db_name or db_path)
+            self.conn = sqlite3.connect(db_path)
             self.cursor = self.conn.cursor()
-
-            columns = "id INTEGER PRIMARY KEY AUTOINCREMENT, ip TEXT UNIQUE, last_tested TIMESTAMP"
-            self.cursor.execute(
-                f"CREATE TABLE IF NOT EXISTS {self.table_name} ({columns})"
-            )
         except Exception as err:
-            self.logger.critical(f"Failed to initialize database for Ping: {err}")
+            self.logger.critical(f"Failed to connect to the database: {err}")
+            exit(1)
 
     def process_server_data(self, data):
         if data["ips"] and isinstance(data["ips"], list):
